==> likewise-open_5.4.0.42111.orig.tar.gz: likewise-open-5.4.0.42111/lwio/logging_r/logging.c <==
/* Editor Settings: expandtabs and use 4 spaces for indentation
 * ex: set softtabstop=4 tabstop=8 expandtab shiftwidth=4: *
 * -*- mode: c, c-basic-offset: 4 -*- */

/*
 * Copyright Likewise Software    2004-2008
 * All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the license, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser
 * General Public License for more details.  You should have received a copy
 * of the GNU Lesser General Public License along with this program.  If
 * not, see <http://www.gnu.org/licenses/>.
 *
 * LIKEWISE SOFTWARE MAKES THIS SOFTWARE AVAILABLE UNDER OTHER LICENSING
 * TERMS AS WELL.  IF YOU HAVE ENTERED INTO A SEPARATE LICENSE AGREEMENT
 * WITH LIKEWISE SOFTWARE, THEN YOU MAY ELECT TO USE THE SOFTWARE UNDER THE
 * TERMS OF THAT SOFTWARE LICENSE AGREEMENT INSTEAD OF THE TERMS OF THE GNU
 * LESSER GENERAL PUBLIC LICENSE, NOTWITHSTANDING THE ABOVE NOTICE.  IF YOU
 * HAVE QUESTIONS, OR WISH TO REQUEST A COPY OF THE ALTERNATE LICENSING
 * TERMS OFFERED BY LIKEWISE SOFTWARE, PLEASE CONTACT LIKEWISE SOFTWARE AT
 * license@likewisesoftware.com
 */

/*
 * Copyright (C) Likewise Software. All rights reserved.
 *
 * Module Name:
 *
 *        logging.c
 *
 * Abstract:
 *
 *        Likewise IO (LWIO)
 *
 *        Logging API (Private Header)
 * 
 *        Thread Safe
 *
 * Authors: Sriram Nambakam (snambakam@likewisesoftware.com)
 * 
 */
#include "includes.h"

DWORD
SMBInitLogging_r(
    PCSTR         pszProgramName,
    LWIO_LOG_TARGET  logTarget,
    LWIO_LOG_LEVEL   maxAllowedLogLevel,
    PCSTR         pszPath
    )
{
    DWORD dwError = 0;
    
    LWIO_LOCK_LOGGER;
    
    dwError = SMBInitLogging(
                    pszProgramName,
                    logTarget,
                    maxAllowedLogLevel,
                    pszPath);
    
    LWIO_UNLOCK_LOGGER;
    
    return dwError;
}

DWORD
SMBLogGetInfo_r(
    PLWIO_LOG_INFO* ppLogInfo
    )
{
    DWORD dwError = 0;
    
    LWIO_LOCK_LOGGER;
    
    dwError = SMBLogGetInfo(ppLogInfo);
    
    LWIO_UNLOCK_LOGGER;
    
    return dwError;    
}

DWORD
SMBLogSetInfo_r(
    PLWIO_LOG_INFO pLogInfo
    )
{
    DWORD dwError = 0;
    
    LWIO_LOCK_LOGGER;
    
    dwError = SMBLogSetInfo(pLogInfo);
    
    LWIO_UNLOCK_LOGGER;
    
    return dwError;        
}

DWORD
SMBShutdownLogging_r(
    VOID
    )
{
    DWORD dwError = 0;
    
    LWIO_LOCK_LOGGER;
    
    dwError = SMBShutdownLogging();
    
    LWIO_UNLOCK_LOGGER;
    
    return dwError;
}

==> likewise-open_6.1.0.406.orig.tar.gz: likewise-open-6.1.0.406/lwio/logging_r/logging.c <==
/* Editor Settings: expandtabs and use 4 spaces for indentation
 * ex: set softtabstop=4 tabstop=8 expandtab shiftwidth=4: *
 * -*- mode: c, c-basic-offset: 4 -*- */

/*
 * Copyright Likewise Software    2004-2008
 * All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the license, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser
 * General Public License for more details.  You should have received a copy
 * of the GNU Lesser General Public License along with this program.  If
 * not, see <http://www.gnu.org/licenses/>.
 *
 * LIKEWISE SOFTWARE MAKES THIS SOFTWARE AVAILABLE UNDER OTHER LICENSING
 * TERMS AS WELL.  IF YOU HAVE ENTERED INTO A SEPARATE LICENSE AGREEMENT
 * WITH LIKEWISE SOFTWARE, THEN YOU MAY ELECT TO USE THE SOFTWARE UNDER THE
 * TERMS OF THAT SOFTWARE LICENSE AGREEMENT INSTEAD OF THE TERMS OF THE GNU
 * LESSER GENERAL PUBLIC LICENSE, NOTWITHSTANDING THE ABOVE NOTICE.  IF YOU
 * HAVE QUESTIONS, OR WISH TO REQUEST A COPY OF THE ALTERNATE LICENSING
 * TERMS OFFERED BY LIKEWISE SOFTWARE, PLEASE CONTACT LIKEWISE SOFTWARE AT
 * license@likewisesoftware.com
 */

/*
 * Copyright (C) Likewise Software. All rights reserved.
 *
 * Module Name:
 *
 *        logging.c
 *
 * Abstract:
 *
 *        Likewise IO (LWIO)
 *
 *        Logging API (Private Header)
 * 
 *        Thread Safe
 *
 * Authors: Sriram Nambakam (snambakam@likewisesoftware.com)
 * 
 */
#include "includes.h"

DWORD
LwioInitLogging_r(
    PCSTR         pszProgramName,
    LWIO_LOG_TARGET  logTarget,
    LWIO_LOG_LEVEL   maxAllowedLogLevel,
    PCSTR         pszPath
    )
{
    DWORD dwError = 0;
    
    LWIO_LOCK_LOGGER;
    
    dwError = LwioInitLogging(
                    pszProgramName,
                    logTarget,
                    maxAllowedLogLevel,
                    pszPath);
    
    LWIO_UNLOCK_LOGGER;
    
    return dwError;
}

DWORD
LwioLogGetInfo_r(
    PLWIO_LOG_INFO* ppLogInfo
    )
{
    DWORD dwError = 0;
    
    LWIO_LOCK_LOGGER;
    
    dwError = LwioLogGetInfo(ppLogInfo);
    
    LWIO_UNLOCK_LOGGER;
    
    return dwError;    
}

DWORD
LwioLogSetInfo_r(
    PLWIO_LOG_INFO pLogInfo
    )
{
    DWORD dwError = 0;
    
    LWIO_LOCK_LOGGER;
    
    dwError = LwioLogSetInfo(pLogInfo);
    
    LWIO_UNLOCK_LOGGER;
    
    return dwError;        
}

DWORD
LwioShutdownLogging_r(
    VOID
    )
{
    DWORD dwError = 0;
    
    LWIO_LOCK_LOGGER;
    
    dwError = LwioShutdownLogging();
    
    LWIO_UNLOCK_LOGGER;
    
    return dwError;
}
